@@ -20,12 +20,11 @@ from src.daemon.windows_signal import kill
 from src.server.server import ssl_context_for_root, ssl_context_for_server
 from src.ssl.create_ssl import get_mozzila_ca_crt
 from src.util.chia_logging import initialize_logging
-from src.util.config import load_config, save_config
+from src.util.config import load_config
 from src.util.json_util import dict_to_json_str
 from src.util.path import mkdir
 from src.util.service_groups import validate_service
 from src.util.setproctitle import setproctitle
-from src.util.validate_alert import validate_alert
 from src.util.ws_message import WsRpcMessage, create_payload, format_response
 
 io_pool_exc = ThreadPoolExecutor()
@@ -107,9 +106,6 @@ async def ping():
     return response
 
 
-not_launched_error_message = "Network not launched yet, waiting for genesis challenge"
-
-
 class WebSocketServer:
     def __init__(self, root_path: Path, ca_crt_path: Path, ca_key_path: Path, crt_path: Path, key_path: Path):
         self.root_path = root_path
@@ -125,7 +121,6 @@ class WebSocketServer:
         self.websocket_server = None
         self.ssl_context = ssl_context_for_server(ca_crt_path, ca_key_path, crt_path, key_path)
         self.shut_down = False
-        self.genesis_initialized = False
 
     async def start(self):
         self.log.info("Starting Daemon Server")
@@ -148,15 +143,6 @@ class WebSocketServer:
             ping_timeout=300,
             ssl=self.ssl_context,
         )
-        selected = self.net_config["selected_network"]
-        challenge = self.net_config["network_overrides"]["constants"][selected]["GENESIS_CHALLENGE"]
-
-        if challenge is None:
-            self.genesis_initialized = False
-            self.alert_task = asyncio.create_task(self.check_for_alerts())
-        else:
-            self.alert_task = None
-            self.genesis_initialized = True
         self.log.info("Waiting Daemon WebSocketServer closure")
 
     def cancel_task_safe(self, task: Optional[asyncio.Task]):
@@ -171,47 +157,8 @@ class WebSocketServer:
         self.cancel_task_safe(self.ping_job)
         await self.exit()
         self.websocket_server.close()
-        self.cancel_task_safe(self.alert_task)
         return {"success": True}
 
-    async def check_for_alerts(self):
-        while True:
-            try:
-                if self.shut_down:
-                    break
-                await asyncio.sleep(2)
-
-                selected = self.net_config["selected_network"]
-                alert_url = self.net_config["ALERTS_URL"]
-                log.debug("Fetching alerts")
-                response = await fetch(alert_url)
-                log.debug(f"Fetched alert: {response}")
-                if response is None:
-                    continue
-
-                json_response = json.loads(response)
-                if "data" in json_response:
-                    pubkey = self.net_config["CHIA_ALERTS_PUBKEY"]
-                    validated = validate_alert(response, pubkey)
-                    if validated is False:
-                        self.log.error(f"Error unable to validate alert! {response}")
-                        continue
-
-                    data = json_response["data"]
-                    data_json = json.loads(data)
-                    if data_json["ready"] is False:
-                        # Network not launched yet
-                        log.info("Network is not ready yet")
-                        continue
-
-                    challenge = data_json["genesis_challenge"]
-                    self.net_config["network_overrides"]["constants"][selected]["GENESIS_CHALLENGE"] = challenge
-                    save_config(self.root_path, "config.yaml", self.net_config)
-                    self.genesis_initialized = True
-                    break
-            except Exception as e:
-                log.error(f"Exception in check alerts task: {e}")
-
     async def safe_handle(self, websocket: WebSocketServerProtocol, path: str):
         service_name = ""
         try:
@@ -342,7 +289,7 @@ class WebSocketServer:
         return full_response, [websocket]
 
     def get_status(self):
-        response = {"success": True, "genesis_initialized": self.genesis_initialized}
+        response = {"success": True, "genesis_initialized": True}
         return response
 
     def plot_queue_to_payload(self, plot_queue_item):
