@@ -1,45 +1,71 @@
-import yaml
 import argparse
+import os
+import shutil
+import sys
 from pathlib import Path
+from typing import Any, Callable, Dict, Optional, Union
+
 import pkg_resources
-from typing import Dict, Any, Callable, Optional, Union
-from src.path import mkdir, path_from_root
+import yaml
+
+from src.util.path import mkdir
 
 
-def migrate_config_file(filename: Union[str, Path], path: Path) -> None:
-    filepath = Path(filename)
-    default_config_file = pkg_resources.resource_string(
-        __name__, f"initial-{filepath.parts[-1]}"
-    ).decode()
-    mkdir(str(path.parent))
-    with open(path, "w") as f:
-        f.write(default_config_file)
+def initial_config_file(filename: Union[str, Path]) -> str:
+    return pkg_resources.resource_string(__name__, f"initial-{filename}").decode()
 
 
-def save_config(filename: Union[str, Path], config_data):
-    path = path_from_root("config") / filename
-    with open(path, "w") as f:
+def create_default_chia_config(root_path: Path) -> None:
+    for filename in ["config.yaml"]:
+        default_config_file_data = initial_config_file(filename)
+        path = config_path_for_filename(root_path, filename)
+        mkdir(path.parent)
+        with open(path, "w") as f:
+            f.write(default_config_file_data)
+
+
+def config_path_for_filename(root_path: Path, filename: Union[str, Path]) -> Path:
+    path_filename = Path(filename)
+    if path_filename.is_absolute():
+        return path_filename
+    return root_path / "config" / filename
+
+
+def save_config(root_path: Path, filename: Union[str, Path], config_data: Any):
+    path = config_path_for_filename(root_path, filename)
+    with open(path.with_suffix("." + str(os.getpid())), "w") as f:
         yaml.safe_dump(config_data, f)
+    shutil.move(str(path.with_suffix("." + str(os.getpid()))), path)
 
 
-def load_config(filename: Union[str, Path], sub_config: Optional[str] = None) -> Dict:
-    path = path_from_root("config") / filename
+def load_config(
+    root_path: Path,
+    filename: Union[str, Path],
+    sub_config: Optional[str] = None,
+    exit_on_error=True,
+) -> Dict:
+    path = config_path_for_filename(root_path, filename)
     if not path.is_file():
-        migrate_config_file(filename, path)
+        if not exit_on_error:
+            raise ValueError("Config not found")
+        print(f"can't find {path}")
+        print("** please run `chia init` to migrate or create new config files **")
+        # TODO: fix this hack
+        sys.exit(-1)
+    r = yaml.safe_load(open(path, "r"))
     if sub_config is not None:
-        return yaml.safe_load(open(path, "r"))[sub_config]
-    else:
-        return yaml.safe_load(open(path, "r"))
+        r = r.get(sub_config)
+    return r
 
 
-def load_config_cli(filename: str, sub_config: Optional[str] = None) -> Dict:
+def load_config_cli(root_path: Path, filename: str, sub_config: Optional[str] = None) -> Dict:
     """
     Loads configuration from the specified filename, in the config directory,
     and then overrides any properties using the passed in command line arguments.
     Nested properties in the config file can be used in the command line with ".",
     for example --farmer_peer.host. Does not support lists.
     """
-    config = load_config(filename, sub_config)
+    config = load_config(root_path, filename, sub_config)
 
     flattened_props = flatten_properties(config)
     parser = argparse.ArgumentParser()
@@ -79,11 +105,11 @@ def unflatten_properties(config: Dict):
 
 
 def add_property(d: Dict, partial_key: str, value: Any):
-    key_1, key_2 = partial_key.split(".")
+    key_1, key_2 = partial_key.split(".", maxsplit=1)
     if key_1 not in d:
         d[key_1] = {}
     if "." in key_2:
-        add_property(d, key_2, value)
+        add_property(d[key_1], key_2, value)
     else:
         d[key_1][key_2] = value
 
