@@ -1,28 +1,34 @@
 import dataclasses
-from typing import Any, List, Type, Union, get_type_hints
+import sys
+from typing import Any, List, Optional, Tuple, Type, Union, get_type_hints
+
+if sys.version_info < (3, 8):
+
+    def get_args(t: Type[Any]) -> Tuple[Any, ...]:
+        return getattr(t, "__args__", ())
+
+    def get_origin(t: Type[Any]) -> Optional[Type[Any]]:
+        return getattr(t, "__origin__", None)
+
+
+else:
+
+    from typing import get_args, get_origin
 
 
 def is_type_List(f_type: Type) -> bool:
-    return (
-        hasattr(f_type, "__origin__") and f_type.__origin__ == list
-    ) or f_type == list
+    return (get_origin(f_type) is not None and get_origin(f_type) == list) or f_type == list
 
 
 def is_type_SpecificOptional(f_type) -> bool:
     """
     Returns true for types such as Optional[T], but not Optional, or T.
     """
-    return (
-        hasattr(f_type, "__origin__")
-        and f_type.__origin__ == Union
-        and f_type.__args__[1]() is None
-    )
+    return get_origin(f_type) is not None and f_type.__origin__ == Union and get_args(f_type)[1]() is None
 
 
 def is_type_Tuple(f_type: Type) -> bool:
-    return (
-        hasattr(f_type, "__origin__") and f_type.__origin__ == tuple
-    ) or f_type == tuple
+    return (get_origin(f_type) is not None and get_origin(f_type) == tuple) or f_type == tuple
 
 
 def strictdataclass(cls: Any):
@@ -37,8 +43,8 @@ def strictdataclass(cls: Any):
         def parse_item(self, item: Any, f_name: str, f_type: Type) -> Any:
             if is_type_List(f_type):
                 collected_list: List = []
-                inner_type: Type = f_type.__args__[0]
-                assert inner_type != List.__args__[0]  # type: ignore
+                inner_type: Type = get_args(f_type)[0]
+                # wjb assert inner_type != get_args(List)[0]  # type: ignore
                 if not is_type_List(type(item)):
                     raise ValueError(f"Wrong type for {f_name}, need a list.")
                 for el in item:
@@ -48,26 +54,27 @@ def strictdataclass(cls: Any):
                 if item is None:
                     return None
                 else:
-                    inner_type: Type = f_type.__args__[0]  # type: ignore
+                    inner_type: Type = get_args(f_type)[0]  # type: ignore
                     return self.parse_item(item, f_name, inner_type)
             if is_type_Tuple(f_type):
                 collected_list = []
                 if not is_type_Tuple(type(item)) and not is_type_List(type(item)):
                     raise ValueError(f"Wrong type for {f_name}, need a tuple.")
-                if len(item) != len(f_type.__args__):
+                if len(item) != len(get_args(f_type)):
                     raise ValueError(f"Wrong number of elements in tuple {f_name}.")
                 for i in range(len(item)):
-                    inner_type = f_type.__args__[i]
+                    inner_type = get_args(f_type)[i]
                     tuple_item = item[i]
-                    collected_list.append(
-                        self.parse_item(tuple_item, f_name, inner_type)
-                    )
+                    collected_list.append(self.parse_item(tuple_item, f_name, inner_type))
                 return tuple(collected_list)
             if not isinstance(item, f_type):
                 try:
                     item = f_type(item)
                 except (TypeError, AttributeError, ValueError):
-                    item = f_type.from_bytes(item)
+                    try:
+                        item = f_type.from_bytes(item)
+                    except Exception:
+                        item = f_type.from_bytes(bytes(item))
             if not isinstance(item, f_type):
                 raise ValueError(f"Wrong type for {f_name}")
             return item
@@ -78,9 +85,7 @@ def strictdataclass(cls: Any):
             for (f_name, f_type) in fields.items():
                 if f_name not in data:
                     raise ValueError(f"Field {f_name} not present")
-                object.__setattr__(
-                    self, f_name, self.parse_item(data[f_name], f_name, f_type)
-                )
+                object.__setattr__(self, f_name, self.parse_item(data[f_name], f_name, f_type))
 
     class NoTypeChecking:
         __no_type_check__ = True
